@@ -142,7 +142,7 @@ def map_enums(table, df):
             elif col == "methodology":
                 df[col] = df[col].apply(lambda x: reverse_mapping.get(x, methodology_duplicate_mapping(x)))
             else:
-                df[col] = df[col].map(reverse_mapping).where(pd.notnull(df[col]), None)
+                df[col] = df[col].apply(lambda x: reverse_mapping.get(x, x))
 
 def map_co_benefits_to_enums_cadt(value):
     return constants.cadt_co_benifit_enum_map.get(value, None)
@@ -229,7 +229,7 @@ def methodology_duplicate_mapping(methodology):
         "GS Methodology for Improved Cook stoves and Kitchen Regimes v1.": enums.Methodology.GsMSMethodologyForEfficientCookstovesV1.name,
         "GS Methodology for Improved Cook stoves and Kitchen Regimes v2.": enums.Methodology.GsMSMethodologyForEfficientCookstovesV1.name,
         
-    }.get(methodology, None)
+    }.get(methodology, methodology)
 
 def project_type_duplicate_mapping(project_type):
     return {
@@ -278,13 +278,13 @@ def project_type_duplicate_mapping(project_type):
         "Small, Low - Impact Hydro" : enums.ProjectType.Hydro.name,
         "Other": enums.ProjectType.Other.name,
 
-    }.get(project_type, None)
+    }.get(project_type, project_type)
 
 def validation_body_duplicate_mapping(validation_body):
     return {
         "SCS Global Services (Scientific Certification Systems)": enums.ValidationBody.SCSGlobalServices.name,
         "TÜV SÜD America, Inc. - Ruby Canyon": enums.ValidationBody.TUVSUDAmericaIncRubyCanyon.name,
-    }.get(validation_body, None)
+    }.get(validation_body, validation_body)
 
 def project_sector_duplicate_mapping(sector):
     return {
@@ -293,7 +293,7 @@ def project_sector_duplicate_mapping(sector):
         "Fugitive emissions from fuels (solid, oil and gas)" : enums.ProjectSector.FugitiveEmissionsFromFuels.name,
         "Chemical Industries" : enums.ProjectSector.ChemicalIndustries.name,
         "Energy Distribution" : enums.ProjectSector.EnergyDistribution.name,
-    }.get(sector, None)
+    }.get(sector, sector)
 
 def map_project_size(project_size):
     project_size = project_size.strip().lower()
@@ -302,11 +302,12 @@ def map_project_size(project_size):
         'Micro scale': enums.ProjectSize.Small.name,
         'Microscale' : enums.ProjectSize.Small.name,
         'large scale': enums.ProjectSize.Large.name,
-    }.get(project_size, None)
+    }.get(project_size, project_size)
 
 def map_countries_to_enums(countries):
     """
     Map country codes to their corresponding Enum names.
+    If a country code does not match, retain the original country code.
     """
     mapper = {
         'US': enums.Countries.UnitedStatesOfAmerica.name,
@@ -322,4 +323,4 @@ def map_countries_to_enums(countries):
         'TH': enums.Countries.Thailand.name,
         'SA': enums.Countries.SaudiArabia.name,
     }
-    return countries.map(mapper).where(pd.notnull(countries), None)
+    return countries.apply(lambda x: mapper.get(x, x))
